@@ -717,7 +717,7 @@ namespace NUnit.Framework.Constraints
 
         /// <summary>
         /// Returns a constraint that succeeds if the actual
-        /// value matches the Regex pattern supplied as an argument.
+        /// value matches the regular expression supplied as an argument.
         /// </summary>
         public RegexConstraint Matches(string pattern)
         {
@@ -726,7 +726,7 @@ namespace NUnit.Framework.Constraints
 
         /// <summary>
         /// Returns a constraint that succeeds if the actual
-        /// value matches the Regex pattern supplied as an argument.
+        /// value matches the regular expression supplied as an argument.
         /// </summary>
         public RegexConstraint StringMatching(string pattern)
         {
@@ -776,7 +776,16 @@ namespace NUnit.Framework.Constraints
 
         #region InRange
 
-#if !CLR_2_0 && !CLR_4_0
+#if CLR_2_0 || CLR_4_0
+        /// <summary>
+        /// Returns a constraint that tests whether the actual value falls 
+        /// within a specified range.
+        /// </summary>
+        public RangeConstraint<T> InRange<T>(T from, T to) where T : IComparable<T>
+        {
+            return (RangeConstraint<T>)this.Append(new RangeConstraint<T>(from, to));
+        }
+#else
         /// <summary>
         /// Returns a constraint that tests whether the actual value falls 
         /// within a specified range.
@@ -789,20 +798,5 @@ namespace NUnit.Framework.Constraints
 
         #endregion
 
-        #region InRange<T>
-
-#if CLR_2_0 || CLR_4_0
-        /// <summary>
-        /// Returns a constraint that tests whether the actual value falls 
-        /// within a specified range.
-        /// </summary>
-        public RangeConstraint<T> InRange<T>(T from, T to) where T : IComparable<T>
-        {
-            return (RangeConstraint<T>)this.Append(new RangeConstraint<T>(from, to));
-        }
-#endif
-
-        #endregion
-
     }
 }
